[go: nahoru, domu]

VT: Rename "shared element" to "view transition"

Renaming some instances missed in previous renames.

Change-Id: I18c14df9def3e38014779df3b22692f384c6e434
Reviewed-on: https://chromium-review.googlesource.com/c/chromium/src/+/4182595
Reviewed-by: Vladimir Levin <vmpstr@chromium.org>
Reviewed-by: Jeremy Roman <jbroman@chromium.org>
Reviewed-by: danakj <danakj@chromium.org>
Commit-Queue: David Bokan <bokan@chromium.org>
Cr-Commit-Position: refs/heads/main@{#1095241}
diff --git a/cc/BUILD.gn b/cc/BUILD.gn
index 18a09f3..a43b848 100644
--- a/cc/BUILD.gn
+++ b/cc/BUILD.gn
@@ -437,10 +437,10 @@
     "trees/viewport_layers.cc",
     "trees/viewport_layers.h",
     "trees/viewport_property_ids.h",
+    "view_transition/view_transition_element_id.cc",
+    "view_transition/view_transition_element_id.h",
     "view_transition/view_transition_request.cc",
     "view_transition/view_transition_request.h",
-    "view_transition/view_transition_shared_element_id.cc",
-    "view_transition/view_transition_shared_element_id.h",
   ]
 
   public_deps = [
diff --git a/cc/animation/animation_host.cc b/cc/animation/animation_host.cc
index 4ccda6e..91b23dc 100644
--- a/cc/animation/animation_host.cc
+++ b/cc/animation/animation_host.cc
@@ -155,13 +155,12 @@
   has_smil_animation_.Write(*this) = has_smil_animation;
 }
 
-bool AnimationHost::HasSharedElementTransition() const {
-  return has_shared_element_transition_.Read(*this);
+bool AnimationHost::HasViewTransition() const {
+  return has_view_transition_.Read(*this);
 }
 
-void AnimationHost::SetHasSharedElementTransition(
-    bool has_shared_element_transition) {
-  has_shared_element_transition_.Write(*this) = has_shared_element_transition;
+void AnimationHost::SetHasViewTransition(bool has_view_transition) {
+  has_view_transition_.Write(*this) = has_view_transition;
 }
 
 void AnimationHost::SetCurrentFrameHadRaf(bool current_frame_had_raf) {
@@ -345,7 +344,7 @@
   host_impl->SetHasCanvasInvalidation(HasCanvasInvalidation());
   host_impl->SetHasInlineStyleMutation(HasJSAnimation());
   host_impl->SetHasSmilAnimation(HasSmilAnimation());
-  host_impl->SetHasSharedElementTransition(HasSharedElementTransition());
+  host_impl->SetHasViewTransition(HasViewTransition());
 
   if (needs_push_properties()) {
     needs_push_properties_.Write(*this) = false;
diff --git a/cc/animation/animation_host.h b/cc/animation/animation_host.h
index b22c471..1f5f2e4 100644
--- a/cc/animation/animation_host.h
+++ b/cc/animation/animation_host.h
@@ -209,7 +209,7 @@
   bool HasCanvasInvalidation() const override;
   bool HasJSAnimation() const override;
   bool HasSmilAnimation() const override;
-  bool HasSharedElementTransition() const override;
+  bool HasViewTransition() const override;
 
   // Starts/stops throughput tracking represented by |sequence_id|.
   void StartThroughputTracking(TrackedAnimationSequenceId sequence_id);
@@ -219,7 +219,7 @@
   void SetHasCanvasInvalidation(bool has_canvas_invalidation);
   void SetHasInlineStyleMutation(bool has_inline_style_mutation);
   void SetHasSmilAnimation(bool has_svg_smil_animation);
-  void SetHasSharedElementTransition(bool hash_shared_element_transition);
+  void SetHasViewTransition(bool has_view_transition);
   void SetCurrentFrameHadRaf(bool current_frame_had_raf);
   void SetNextFrameHasPendingRaf(bool next_frame_has_pending_raf);
 
@@ -289,7 +289,7 @@
   ProtectedSequenceReadable<bool> has_canvas_invalidation_{false};
   ProtectedSequenceReadable<bool> has_inline_style_mutation_{false};
   ProtectedSequenceReadable<bool> has_smil_animation_{false};
-  ProtectedSequenceReadable<bool> has_shared_element_transition_{false};
+  ProtectedSequenceReadable<bool> has_view_transition_{false};
 
   ProtectedSequenceWritable<PendingThroughputTrackerInfos>
       pending_throughput_tracker_infos_;
diff --git a/cc/layers/render_surface_impl.h b/cc/layers/render_surface_impl.h
index 2e21ab5..4504b8e 100644
--- a/cc/layers/render_surface_impl.h
+++ b/cc/layers/render_surface_impl.h
@@ -18,7 +18,7 @@
 #include "cc/layers/layer_collections.h"
 #include "cc/trees/occlusion.h"
 #include "cc/trees/property_tree.h"
-#include "cc/view_transition/view_transition_shared_element_id.h"
+#include "cc/view_transition/view_transition_element_id.h"
 #include "components/viz/common/quads/compositor_render_pass.h"
 #include "components/viz/common/quads/shared_quad_state.h"
 #include "components/viz/common/surfaces/subtree_capture_id.h"
diff --git a/cc/trees/effect_node.h b/cc/trees/effect_node.h
index 4c305773..c329bea 100644
--- a/cc/trees/effect_node.h
+++ b/cc/trees/effect_node.h
@@ -8,7 +8,7 @@
 #include "cc/cc_export.h"
 #include "cc/paint/element_id.h"
 #include "cc/paint/filter_operations.h"
-#include "cc/view_transition/view_transition_shared_element_id.h"
+#include "cc/view_transition/view_transition_element_id.h"
 #include "components/viz/common/surfaces/subtree_capture_id.h"
 #include "components/viz/common/view_transition_element_resource_id.h"
 #include "third_party/abseil-cpp/absl/types/optional.h"
diff --git a/cc/trees/layer_tree_host_impl.cc b/cc/trees/layer_tree_host_impl.cc
index 12a1491e..a8d0fce 100644
--- a/cc/trees/layer_tree_host_impl.cc
+++ b/cc/trees/layer_tree_host_impl.cc
@@ -780,7 +780,7 @@
       mutator_host_->HasSmilAnimation()) {
     frame_trackers_.StartSequence(
         FrameSequenceTrackerType::kMainThreadAnimation);
-    if (mutator_host_->HasSharedElementTransition()) {
+    if (mutator_host_->HasViewTransition()) {
       frame_trackers_.StartSequence(
           FrameSequenceTrackerType::kSETMainThreadAnimation);
     }
@@ -2546,7 +2546,7 @@
         FrameSequenceTrackerType::kMainThreadAnimation);
     frame_trackers_.StopSequence(
         FrameSequenceTrackerType::kSETMainThreadAnimation);
-  } else if (!mutator_host_->HasSharedElementTransition()) {
+  } else if (!mutator_host_->HasViewTransition()) {
     frame_trackers_.StopSequence(
         FrameSequenceTrackerType::kSETMainThreadAnimation);
   }
@@ -4302,7 +4302,7 @@
         FrameSequenceTrackerType::kCompositorAnimation);
   }
 
-  if (animated && mutator_host_->HasSharedElementTransition()) {
+  if (animated && mutator_host_->HasViewTransition()) {
     frame_trackers_.StartSequence(
         FrameSequenceTrackerType::kSETCompositorAnimation);
   } else {
diff --git a/cc/trees/mutator_host.h b/cc/trees/mutator_host.h
index aed5595..74fddb4 100644
--- a/cc/trees/mutator_host.h
+++ b/cc/trees/mutator_host.h
@@ -141,7 +141,7 @@
   virtual bool HasCanvasInvalidation() const = 0;
   virtual bool HasJSAnimation() const = 0;
   virtual bool HasSmilAnimation() const = 0;
-  virtual bool HasSharedElementTransition() const = 0;
+  virtual bool HasViewTransition() const = 0;
 
   // Iterates through all animations and returns the minimum tick interval.
   // Returns 0 if there is a continuous animation which should be ticked
diff --git a/cc/view_transition/view_transition_shared_element_id.cc b/cc/view_transition/view_transition_element_id.cc
similarity index 95%
rename from cc/view_transition/view_transition_shared_element_id.cc
rename to cc/view_transition/view_transition_element_id.cc
index ed88e6e1..066c5f3 100644
--- a/cc/view_transition/view_transition_shared_element_id.cc
+++ b/cc/view_transition/view_transition_element_id.cc
@@ -2,7 +2,7 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#include "cc/view_transition/view_transition_shared_element_id.h"
+#include "cc/view_transition/view_transition_element_id.h"
 
 #include <sstream>
 #include <string>
diff --git a/cc/view_transition/view_transition_shared_element_id.h b/cc/view_transition/view_transition_element_id.h
similarity index 85%
rename from cc/view_transition/view_transition_shared_element_id.h
rename to cc/view_transition/view_transition_element_id.h
index f3e4118..7590fb5 100644
--- a/cc/view_transition/view_transition_shared_element_id.h
+++ b/cc/view_transition/view_transition_element_id.h
@@ -2,8 +2,8 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef CC_VIEW_TRANSITION_VIEW_TRANSITION_SHARED_ELEMENT_ID_H_
-#define CC_VIEW_TRANSITION_VIEW_TRANSITION_SHARED_ELEMENT_ID_H_
+#ifndef CC_VIEW_TRANSITION_VIEW_TRANSITION_ELEMENT_ID_H_
+#define CC_VIEW_TRANSITION_VIEW_TRANSITION_ELEMENT_ID_H_
 
 #include <stdint.h>
 
@@ -23,7 +23,7 @@
   ViewTransitionElementId(ViewTransitionElementId&&);
   ~ViewTransitionElementId();
 
-  // Add a shared index to this id. It must have a valid document tag.
+  // Add an element index to this id. It must have a valid document tag.
   void AddIndex(uint32_t index);
 
   // Returns true if the document tag matches this id and the index is in the
@@ -61,4 +61,4 @@
 
 }  // namespace cc
 
-#endif  // CC_VIEW_TRANSITION_VIEW_TRANSITION_SHARED_ELEMENT_ID_H_
+#endif  // CC_VIEW_TRANSITION_VIEW_TRANSITION_ELEMENT_ID_H_
diff --git a/cc/view_transition/view_transition_request.cc b/cc/view_transition/view_transition_request.cc
index b7b24b9..81db4a28 100644
--- a/cc/view_transition/view_transition_request.cc
+++ b/cc/view_transition/view_transition_request.cc
@@ -14,7 +14,7 @@
 #include "base/functional/callback_helpers.h"
 #include "base/memory/ptr_util.h"
 #include "base/ranges/algorithm.h"
-#include "cc/view_transition/view_transition_shared_element_id.h"
+#include "cc/view_transition/view_transition_element_id.h"
 #include "components/viz/common/quads/compositor_frame_transition_directive.h"
 #include "components/viz/common/quads/compositor_render_pass.h"
 
diff --git a/cc/view_transition/view_transition_request.h b/cc/view_transition/view_transition_request.h
index 6ff8490..6d27beb0 100644
--- a/cc/view_transition/view_transition_request.h
+++ b/cc/view_transition/view_transition_request.h
@@ -13,7 +13,7 @@
 
 #include "base/functional/callback.h"
 #include "cc/cc_export.h"
-#include "cc/view_transition/view_transition_shared_element_id.h"
+#include "cc/view_transition/view_transition_element_id.h"
 #include "components/viz/common/quads/compositor_frame_transition_directive.h"
 #include "components/viz/common/quads/compositor_render_pass.h"
 
diff --git a/content/web_test/renderer/web_test_content_settings_client.cc b/content/web_test/renderer/web_test_content_settings_client.cc
index c9f8dfa9..f1814d4 100644
--- a/content/web_test/renderer/web_test_content_settings_client.cc
+++ b/content/web_test/renderer/web_test_content_settings_client.cc
@@ -64,8 +64,8 @@
   return enabled_per_settings || flags_->running_insecure_content_allowed();
 }
 
-bool WebTestContentSettingsClient::
-    IncreaseSharedElementTransitionCallbackTimeout() const {
+bool WebTestContentSettingsClient::IncreaseViewTransitionCallbackTimeout()
+    const {
   // In tests we want larger timeout to account for slower running tests.
   return true;
 }
diff --git a/content/web_test/renderer/web_test_content_settings_client.h b/content/web_test/renderer/web_test_content_settings_client.h
index 6368b0ad..1b15d42 100644
--- a/content/web_test/renderer/web_test_content_settings_client.h
+++ b/content/web_test/renderer/web_test_content_settings_client.h
@@ -35,7 +35,7 @@
   bool AllowStorageAccessSync(StorageType storage_type) override;
   bool AllowRunningInsecureContent(bool enabled_per_settings,
                                    const blink::WebURL& url) override;
-  bool IncreaseSharedElementTransitionCallbackTimeout() const override;
+  bool IncreaseViewTransitionCallbackTimeout() const override;
 
  private:
   TestRunner* const test_runner_;
diff --git a/third_party/blink/renderer/core/display_lock/display_lock_context.cc b/third_party/blink/renderer/core/display_lock/display_lock_context.cc
index 4338f07..7714a2a 100644
--- a/third_party/blink/renderer/core/display_lock/display_lock_context.cc
+++ b/third_party/blink/renderer/core/display_lock/display_lock_context.cc
@@ -69,7 +69,7 @@
   DetermineIfSubtreeHasFocus();
   DetermineIfSubtreeHasSelection();
   DetermineIfSubtreeHasTopLayerElement();
-  DetermineIfInSharedElementTransitionChain();
+  DetermineIfInViewTransitionElementChain();
 }
 
 void DisplayLockContext::SetRequestedState(EContentVisibility state,
@@ -887,7 +887,7 @@
   DetermineIfSubtreeHasFocus();
   DetermineIfSubtreeHasSelection();
   DetermineIfSubtreeHasTopLayerElement();
-  DetermineIfInSharedElementTransitionChain();
+  DetermineIfInViewTransitionElementChain();
 }
 
 void DisplayLockContext::WillStartLifecycleUpdate(const LocalFrameView& view) {
@@ -1162,29 +1162,31 @@
   }
 }
 
-void DisplayLockContext::DetermineIfInSharedElementTransitionChain() {
-  ResetAndDetermineIfAncestorIsSharedElement();
-  if (ConnectedToView())
-    document_->GetDisplayLockDocumentState().UpdateSharedElementAncestorLocks();
+void DisplayLockContext::DetermineIfInViewTransitionElementChain() {
+  ResetAndDetermineIfAncestorIsViewTransitionElement();
+  if (ConnectedToView()) {
+    document_->GetDisplayLockDocumentState()
+        .UpdateViewTransitionElementAncestorLocks();
+  }
 }
 
-void DisplayLockContext::ResetInSharedElementTransitionChain() {
-  SetRenderAffectingState(RenderAffectingState::kSharedElementTransitionChain,
+void DisplayLockContext::ResetInViewTransitionElementChain() {
+  SetRenderAffectingState(RenderAffectingState::kViewTransitionElementChain,
                           false);
 }
 
-void DisplayLockContext::SetInSharedElementTransitionChain() {
-  SetRenderAffectingState(RenderAffectingState::kSharedElementTransitionChain,
+void DisplayLockContext::SetInViewTransitionElementChain() {
+  SetRenderAffectingState(RenderAffectingState::kViewTransitionElementChain,
                           true);
 }
 
-bool DisplayLockContext::IsInSharedElementAncestorChain() const {
+bool DisplayLockContext::IsInViewTransitionElementAncestorChain() const {
   return render_affecting_state_[static_cast<int>(
-      RenderAffectingState::kSharedElementTransitionChain)];
+      RenderAffectingState::kViewTransitionElementChain)];
 }
 
-void DisplayLockContext::ResetAndDetermineIfAncestorIsSharedElement() {
-  ResetInSharedElementTransitionChain();
+void DisplayLockContext::ResetAndDetermineIfAncestorIsViewTransitionElement() {
+  ResetInViewTransitionElementChain();
   if (!ConnectedToView())
     return;
 
@@ -1192,7 +1194,7 @@
   if (!transition)
     return;
 
-  bool has_shared_element_ancestor = false;
+  bool has_view_transition_element_ancestor = false;
   for (auto* candidate = element_.Get(); candidate;
        candidate = FlatTreeTraversal::ParentElement(*candidate)) {
     // We don't care about document element as the ancestor, since it's common
@@ -1203,12 +1205,12 @@
     if (auto* layout_object = candidate->GetLayoutObject();
         layout_object &&
         transition->IsRepresentedViaPseudoElements(*layout_object)) {
-      has_shared_element_ancestor = true;
+      has_view_transition_element_ancestor = true;
       break;
     }
   }
-  SetRenderAffectingState(RenderAffectingState::kSharedElementTransitionChain,
-                          has_shared_element_ancestor);
+  SetRenderAffectingState(RenderAffectingState::kViewTransitionElementChain,
+                          has_view_transition_element_ancestor);
 }
 
 void DisplayLockContext::ClearHasTopLayerElement() {
@@ -1331,7 +1333,7 @@
         !state(RenderAffectingState::kAutoStateUnlockedUntilLifecycle) &&
         !state(RenderAffectingState::kAutoUnlockedForPrint) &&
         !state(RenderAffectingState::kSubtreeHasTopLayerElement) &&
-        !state(RenderAffectingState::kSharedElementTransitionChain)));
+        !state(RenderAffectingState::kViewTransitionElementChain)));
 
   if (should_be_locked && !IsLocked())
     Lock();
@@ -1365,8 +1367,8 @@
       return "AutoUnlockedForPrint";
     case RenderAffectingState::kSubtreeHasTopLayerElement:
       return "SubtreeHasTopLayerElement";
-    case RenderAffectingState::kSharedElementTransitionChain:
-      return "SharedElementTransitionChain";
+    case RenderAffectingState::kViewTransitionElementChain:
+      return "ViewTransitionElementChain";
     case RenderAffectingState::kNumRenderAffectingStates:
       break;
   }
diff --git a/third_party/blink/renderer/core/frame/local_frame_view.cc b/third_party/blink/renderer/core/frame/local_frame_view.cc
index 4db8e65f..b3cab45 100644
--- a/third_party/blink/renderer/core/frame/local_frame_view.cc
+++ b/third_party/blink/renderer/core/frame/local_frame_view.cc
@@ -2502,8 +2502,8 @@
       continue;
 
     // ViewTransition mutates the tree and mirrors post layout transform for
-    // shared elements to UA created elements. This may dirty style/layout
-    // requiring another lifecycle update.
+    // transitioning elements to UA created elements. This may dirty
+    // style/layout requiring another lifecycle update.
     needs_to_repeat_lifecycle = RunViewTransitionSteps(target_state);
     if (!needs_to_repeat_lifecycle)
       break;
diff --git a/third_party/blink/renderer/core/frame/local_frame_view.h b/third_party/blink/renderer/core/frame/local_frame_view.h
index bbae408..0c327e9 100644
--- a/third_party/blink/renderer/core/frame/local_frame_view.h
+++ b/third_party/blink/renderer/core/frame/local_frame_view.h
@@ -1010,8 +1010,6 @@
   // StyleEngine instead of the base background color.
   bool ShouldUseColorAdjustBackground() const;
 
-  // Verifies the shared elements for the view transition on this view.
-  void VerifySharedElementsForViewTransition();
   // Append view transition requests from this view into the given vector.
   void AppendViewTransitionRequests(
       WTF::Vector<std::unique_ptr<ViewTransitionRequest>>&);
diff --git a/third_party/blink/renderer/core/page/page_animator.h b/third_party/blink/renderer/core/page/page_animator.h
index 566b828..cd8005a2 100644
--- a/third_party/blink/renderer/core/page/page_animator.h
+++ b/third_party/blink/renderer/core/page/page_animator.h
@@ -60,7 +60,7 @@
   void SetHasSmilAnimation();
   void SetCurrentFrameHadRaf();
   void SetNextFrameHasPendingRaf();
-  void SetHasSharedElementTransition(bool);
+  void SetHasViewTransition(bool);
   void ReportFrameAnimations(cc::AnimationHost* animation_host);
 
  private:
@@ -81,7 +81,7 @@
   // True if there is a raf scheduled for the next frame.
   bool next_frame_has_pending_raf_ = false;
   // True if there is an ongoing view transition.
-  bool has_shared_element_transition_ = false;
+  bool has_view_transition_ = false;
 };
 
 }  // namespace blink
diff --git a/third_party/blink/renderer/core/paint/paint_property_tree_builder.cc b/third_party/blink/renderer/core/paint/paint_property_tree_builder.cc
index 22fcdcef..2b0a957 100644
--- a/third_party/blink/renderer/core/paint/paint_property_tree_builder.cc
+++ b/third_party/blink/renderer/core/paint/paint_property_tree_builder.cc
@@ -67,7 +67,7 @@
 #include "third_party/blink/renderer/platform/graphics/compositing/paint_artifact_compositor.h"
 #include "third_party/blink/renderer/platform/graphics/paint/effect_paint_property_node.h"
 #include "third_party/blink/renderer/platform/graphics/skia/skia_utils.h"
-#include "third_party/blink/renderer/platform/graphics/view_transition_shared_element_id.h"
+#include "third_party/blink/renderer/platform/graphics/view_transition_element_id.h"
 #include "third_party/blink/renderer/platform/wtf/casting.h"
 #include "ui/gfx/geometry/outsets_f.h"
 #include "ui/gfx/geometry/transform.h"
@@ -271,7 +271,7 @@
   ALWAYS_INLINE void UpdateTransformForSVGChild(CompositingReasons);
   ALWAYS_INLINE bool NeedsEffect() const;
   ALWAYS_INLINE bool EffectCanUseCurrentClipAsOutputClip() const;
-  ALWAYS_INLINE void UpdateSharedElementTransitionEffect();
+  ALWAYS_INLINE void UpdateViewTransitionEffect();
   ALWAYS_INLINE void UpdateEffect();
   ALWAYS_INLINE void UpdateFilter();
   ALWAYS_INLINE void UpdateFragmentClip();
@@ -1644,10 +1644,10 @@
   }
 }
 
-void FragmentPaintPropertyTreeBuilder::UpdateSharedElementTransitionEffect() {
+void FragmentPaintPropertyTreeBuilder::UpdateViewTransitionEffect() {
   if (NeedsPaintPropertyUpdate()) {
     if (full_context_.direct_compositing_reasons &
-        CompositingReason::kViewTransitionSharedElement) {
+        CompositingReason::kViewTransitionElement) {
       auto* transition =
           ViewTransitionUtils::GetActiveTransition(object_.GetDocument());
       DCHECK(transition);
@@ -3127,7 +3127,7 @@
       UpdateOffset();
       UpdateTransform();
     }
-    UpdateSharedElementTransitionEffect();
+    UpdateViewTransitionEffect();
     UpdateClipPathClip();
     UpdateEffect();
     UpdateCssClip();
diff --git a/third_party/blink/renderer/core/view_transition/README.md b/third_party/blink/renderer/core/view_transition/README.md
index 25a62c0..d6bcb243 100644
--- a/third_party/blink/renderer/core/view_transition/README.md
+++ b/third_party/blink/renderer/core/view_transition/README.md
@@ -35,10 +35,11 @@
 - The browser executes the Document lifecycle phases (until paint) to generate
   the state required to render a DOM element as an image (bounding box size,
   transform mapping the box to viewport space and relative paint order between
-  elements). This state is tracked for a subset of elements (called shared
-  elements) which should be animated independently during a transition.
+  elements). This state is tracked for a subset of elements called "view
+  transition elements" (or just "transition elements" when the context is clear)
+  which should be animated independently during a transition.
 
-- A tree of pseudo elements is generated to render the shared elements using
+- A tree of pseudo elements is generated to render the transition elements using
   this state. The pseudo element tree is styled after a style recalc pass is
   executed on the author DOM during a Document lifecycle update.
 
@@ -58,30 +59,30 @@
 
 The ::view-transition pseudo element is the root of this pseudo element tree. This
 provides a shared stacking context for painting pseudo elements corresponding to
-a shared element.
+a transition element.
 
-Each shared element is rendered using the following new pseudo elements :
+Each transition element is rendered using the following new pseudo elements :
 
-- ::view-transition-group generates a box which maps to the shared element's quad
-in author DOM.
+- ::view-transition-group generates a box which maps to the transition element's
+quad in author DOM.
 - ::view-transition-image-pair is a box that contains two images representing
-the contents of the old and new shared element. It is isolated to allow for
+the contents of the old and new transition element. It is isolated to allow for
 mix-blend-modes that don't interact with outside content.
-- ::view-transition-old is a replaced element displaying the shared element's
-cached content from the old DOM.
-- ::view-transition-incoming-iage is a replaced element displaying the shared element's
-live content from the new DOM.
+- ::view-transition-old is a replaced element displaying the transition
+element's cached content from the old DOM.
+- ::view-transition-new is a replaced element displaying the
+transition element's live content from the new DOM.
 
-Each shared element is tagged with a developer provided string which can be used
-as a custom ident to uniquely identify and target the corresponding generated
-pseudo elements in UA and developer stylesheets. This string is tracked on the
-PseudoElement class.
+Each transition element is tagged with a developer provided string which can be
+used as a custom ident to uniquely identify and target the corresponding
+generated pseudo elements in UA and developer stylesheets. This string is
+tracked on the PseudoElement class.
 
 ## ViewTransitionElementResourceId
 ViewTransitionElementResourceId is an identifier used to tag the rendered output (called
-a snapshot) of shared elements and the root stacking context generated by the
+a snapshot) of transition elements and the root stacking context generated by the
 compositor. The snapshot provides the content for the ::view-transition-old
-and ::view-transition-incoming-iage elements referenced above.
+and ::view-transition-new elements referenced above.
 
 The snapshot can be in 2 states :
 
@@ -102,8 +103,8 @@
 * Once the cached version has been saved, the developer can update the DOM to
 the new state called the start phase. At this point new_snapshot_id is created
 to tag elements in the new DOM. This ID always refers to a live snapshot and
-provides the content for ::view-transition-incoming-iage pseudo elements.
-The old_snapshot_id now refers to the cached version displayed by
+provides the content for ::view-transition-new pseudo elements. The
+old_snapshot_id now refers to the cached version displayed by
 ::view-transition-old pseudo elements.
 
 ## Viewport Sizes
@@ -149,8 +150,8 @@
 hidden. If the widgets are showing this causes ::view-transition to be
 positioned at a negative offset relative to the fixed viewport (i.e. it's origin
 is underneath the mobile URL bar). This creates a stable coordinate space during
-the transition. Shared element's viewport transforms account for this and are
-computed relative to the snapshot viewport origin.
+the transition. Transition elements' viewport transforms account for this and
+are computed relative to the snapshot viewport origin.
 
 The root snapshot is sized to the snapshot viewport's size, which may be larger
 than the current fixed viewport. Painting is offset within the snapshot so that
diff --git a/third_party/blink/renderer/core/view_transition/view_transition.cc b/third_party/blink/renderer/core/view_transition/view_transition.cc
index ef7a0566..6ec75d8 100644
--- a/third_party/blink/renderer/core/view_transition/view_transition.cc
+++ b/third_party/blink/renderer/core/view_transition/view_transition.cc
@@ -500,12 +500,12 @@
         break;
 
       // Update the lifecycle if needed and discover the elements (deferred to
-      // AddSharedElementsFromCSS).
+      // AddTransitionElementsFromCSS).
       case State::kCaptureTagDiscovery:
         DCHECK(in_main_lifecycle_update_);
         DCHECK_GE(document_->Lifecycle().GetState(),
                   DocumentLifecycle::kCompositingInputsClean);
-        style_tracker_->AddSharedElementsFromCSS();
+        style_tracker_->AddTransitionElementsFromCSS();
         process_next_state = AdvanceTo(State::kCaptureRequestPending);
         DCHECK(process_next_state);
         break;
@@ -607,7 +607,7 @@
             DocumentUpdateReason::kViewTransition);
         DCHECK_GE(document_->Lifecycle().GetState(),
                   DocumentLifecycle::kPrePaintClean);
-        style_tracker_->AddSharedElementsFromCSS();
+        style_tracker_->AddTransitionElementsFromCSS();
         process_next_state = AdvanceTo(State::kAnimateRequestPending);
         DCHECK(process_next_state);
         break;
@@ -784,7 +784,7 @@
   ProcessCurrentState();
 }
 
-bool ViewTransition::NeedsSharedElementEffectNode(
+bool ViewTransition::NeedsViewTransitionEffectNode(
     const LayoutObject& object) const {
   // Layout view always needs an effect node, even if root itself is not
   // transitioning. The reason for this is that we want the root to have an
@@ -793,9 +793,10 @@
   if (IsA<LayoutView>(object))
     return !IsTerminalState(state_);
 
-  // Otherwise check if the layout object has an active shared element.
+  // Otherwise check if the layout object has an active transition element.
   auto* element = DynamicTo<Element>(object.GetNode());
-  return element && style_tracker_ && style_tracker_->IsSharedElement(element);
+  return element && style_tracker_ &&
+         style_tracker_->IsTransitionElement(element);
 }
 
 bool ViewTransition::IsRepresentedViaPseudoElements(
@@ -807,7 +808,7 @@
     return style_tracker_->IsRootTransitioning();
 
   auto* element = DynamicTo<Element>(object.GetNode());
-  return element && style_tracker_->IsSharedElement(element);
+  return element && style_tracker_->IsTransitionElement(element);
 }
 
 PaintPropertyChangeType ViewTransition::UpdateEffect(
@@ -815,35 +816,32 @@
     const EffectPaintPropertyNodeOrAlias& current_effect,
     const ClipPaintPropertyNodeOrAlias* current_clip,
     const TransformPaintPropertyNodeOrAlias* current_transform) {
-  DCHECK(NeedsSharedElementEffectNode(object));
+  DCHECK(NeedsViewTransitionEffectNode(object));
   DCHECK(current_transform);
   DCHECK(current_clip);
 
   EffectPaintPropertyNode::State state;
-  state.direct_compositing_reasons =
-      CompositingReason::kViewTransitionSharedElement;
+  state.direct_compositing_reasons = CompositingReason::kViewTransitionElement;
   state.local_transform_space = current_transform;
   state.output_clip = current_clip;
-  state.view_transition_shared_element_id =
-      ViewTransitionElementId(document_tag_);
+  state.view_transition_element_id = ViewTransitionElementId(document_tag_);
   state.compositor_element_id = CompositorElementIdFromUniqueObjectId(
-      object.UniqueId(),
-      CompositorElementIdNamespace::kSharedElementTransition);
+      object.UniqueId(), CompositorElementIdNamespace::kViewTransitionElement);
   auto* element = DynamicTo<Element>(object.GetNode());
   if (!element) {
     // The only non-element participant is the layout view.
     DCHECK(object.IsLayoutView());
 
     style_tracker_->UpdateRootIndexAndSnapshotId(
-        state.view_transition_shared_element_id,
+        state.view_transition_element_id,
         state.view_transition_element_resource_id);
-    DCHECK(state.view_transition_shared_element_id.valid() ||
+    DCHECK(state.view_transition_element_id.valid() ||
            !style_tracker_->IsRootTransitioning());
     return style_tracker_->UpdateRootEffect(std::move(state), current_effect);
   }
 
   style_tracker_->UpdateElementIndicesAndSnapshotId(
-      element, state.view_transition_shared_element_id,
+      element, state.view_transition_element_id,
       state.view_transition_element_resource_id);
   return style_tracker_->UpdateEffect(element, std::move(state),
                                       current_effect);
@@ -851,7 +849,7 @@
 
 EffectPaintPropertyNode* ViewTransition::GetEffect(
     const LayoutObject& object) const {
-  DCHECK(NeedsSharedElementEffectNode(object));
+  DCHECK(NeedsViewTransitionEffectNode(object));
 
   auto* element = DynamicTo<Element>(object.GetNode());
   if (!element)
@@ -944,8 +942,7 @@
                                     this);
   const base::TimeDelta kTimeout = [this]() {
     if (auto* settings = document_->GetFrame()->GetContentSettingsClient();
-        settings &&
-        settings->IncreaseSharedElementTransitionCallbackTimeout()) {
+        settings && settings->IncreaseViewTransitionCallbackTimeout()) {
       return base::Seconds(15);
     } else {
       return base::Seconds(4);
diff --git a/third_party/blink/renderer/core/view_transition/view_transition_test.cc b/third_party/blink/renderer/core/view_transition/view_transition_test.cc
index f788e1c..b62bdd9 100644
--- a/third_party/blink/renderer/core/view_transition/view_transition_test.cc
+++ b/third_party/blink/renderer/core/view_transition/view_transition_test.cc
@@ -135,7 +135,7 @@
     auto* layout_object = e->GetLayoutObject();
     auto* transition = ViewTransitionUtils::GetActiveTransition(GetDocument());
     return layout_object && transition &&
-           transition->NeedsSharedElementEffectNode(*layout_object);
+           transition->NeedsViewTransitionEffectNode(*layout_object);
   }
 
   void ValidatePseudoElementTree(
@@ -240,7 +240,7 @@
   auto* container_box = To<LayoutBox>(container_pseudo->GetLayoutObject());
   EXPECT_EQ(LayoutSize(100, 100), container_box->Size());
 
-  // Shared elements should not cause a layout shift.
+  // View transition elements should not cause a layout shift.
   auto* target =
       To<LayoutBox>(GetDocument().getElementById("target")->GetLayoutObject());
   EXPECT_FLOAT_EQ(0, GetLayoutShiftTracker().Score());
@@ -301,7 +301,7 @@
   FinishTransition();
 }
 
-TEST_P(ViewTransitionTest, PrepareSharedElementsWantToBeComposited) {
+TEST_P(ViewTransitionTest, PrepareTransitionElementsWantToBeComposited) {
   SetHtmlInnerHTML(R"HTML(
     <style>
       /* TODO(crbug.com/1336462): html.css is parsed before runtime flags are enabled */
@@ -366,7 +366,7 @@
   test::RunPendingTasks();
 }
 
-TEST_P(ViewTransitionTest, StartSharedElementsWantToBeComposited) {
+TEST_P(ViewTransitionTest, StartTransitionElementsWantToBeComposited) {
   SetHtmlInnerHTML(R"HTML(
     <style>
       /* TODO(crbug.com/1336462): html.css is parsed before runtime flags are enabled */
@@ -625,7 +625,7 @@
       kPseudoIdViewTransition));
 }
 
-TEST_P(ViewTransitionTest, ViewTransitionSharedElementInvalidation) {
+TEST_P(ViewTransitionTest, ViewTransitionElementInvalidation) {
   SetHtmlInnerHTML(R"HTML(
     <style>
       /* TODO(crbug.com/1336462): html.css is parsed before runtime flags are enabled */
diff --git a/third_party/blink/renderer/platform/BUILD.gn b/third_party/blink/renderer/platform/BUILD.gn
index 3509513..5b82a79 100644
--- a/third_party/blink/renderer/platform/BUILD.gn
+++ b/third_party/blink/renderer/platform/BUILD.gn
@@ -1148,7 +1148,7 @@
     "graphics/video_frame_sink_bundle.h",
     "graphics/video_frame_submitter.cc",
     "graphics/video_frame_submitter.h",
-    "graphics/view_transition_shared_element_id.h",
+    "graphics/view_transition_element_id.h",
     "graphics/viz_util.cc",
     "graphics/viz_util.h",
     "graphics/web_graphics_context_3d_provider_util.cc",
diff --git a/third_party/blink/renderer/platform/graphics/compositing/paint_artifact_compositor.cc b/third_party/blink/renderer/platform/graphics/compositing/paint_artifact_compositor.cc
index 7049902..c8704dde 100644
--- a/third_party/blink/renderer/platform/graphics/compositing/paint_artifact_compositor.cc
+++ b/third_party/blink/renderer/platform/graphics/compositing/paint_artifact_compositor.cc
@@ -735,8 +735,8 @@
     if (layer.subtree_property_changed())
       root_layer_->SetNeedsCommit();
 
-    auto shared_element_id = layer.ViewTransitionResourceId();
-    if (shared_element_id.IsValid()) {
+    auto transition_resource_id = layer.ViewTransitionResourceId();
+    if (transition_resource_id.IsValid()) {
       host->property_trees()
           ->effect_tree_mutable()
           .AddTransitionPseudoElementEffectId(effect_id);
diff --git a/third_party/blink/renderer/platform/graphics/compositing_reasons.cc b/third_party/blink/renderer/platform/graphics/compositing_reasons.cc
index c7d55aa5..6175bbda 100644
--- a/third_party/blink/renderer/platform/graphics/compositing_reasons.cc
+++ b/third_party/blink/renderer/platform/graphics/compositing_reasons.cc
@@ -115,8 +115,7 @@
      "Ancestor in same 3D rendering context has a hidden backface"},
     {CompositingReason::kTransform3DSceneLeaf, "Transform3DSceneLeaf",
      "Leaf of a 3D scene, for flattening its descendants into that scene"},
-    {CompositingReason::kViewTransitionSharedElement,
-     "ViewTransitionSharedElement",
+    {CompositingReason::kViewTransitionElement, "ViewTransitionElement",
      "This element is shared during view transition"},
     {CompositingReason::kViewTransitionPseudoElement,
      "ViewTransitionContentElement",
diff --git a/third_party/blink/renderer/platform/graphics/compositing_reasons.h b/third_party/blink/renderer/platform/graphics/compositing_reasons.h
index eb910c3..c21c1fa 100644
--- a/third_party/blink/renderer/platform/graphics/compositing_reasons.h
+++ b/third_party/blink/renderer/platform/graphics/compositing_reasons.h
@@ -85,9 +85,9 @@
   /* Link highlight, frame overlay, etc. */                                   \
   V(LayerForOther)                                                            \
                                                                               \
-  /* ViewTransition shared element.                                           \
+  /* ViewTransition element.                                                  \
   See third_party/blink/renderer/core/view_transition/README.md. */           \
-  V(ViewTransitionSharedElement)
+  V(ViewTransitionElement)
 
 class PLATFORM_EXPORT CompositingReason {
   DISALLOW_NEW();
diff --git a/third_party/blink/renderer/platform/graphics/compositor_element_id.h b/third_party/blink/renderer/platform/graphics/compositor_element_id.h
index 906c70c..5c8ddf3 100644
--- a/third_party/blink/renderer/platform/graphics/compositor_element_id.h
+++ b/third_party/blink/renderer/platform/graphics/compositor_element_id.h
@@ -29,7 +29,7 @@
   kTranslateTransform,
   kVerticalScrollbar,
   kHorizontalScrollbar,
-  kSharedElementTransition,
+  kViewTransitionElement,
   kDOMNodeId,
   // The following values are for internal usage only.
   kMax = kDOMNodeId,
diff --git a/third_party/blink/renderer/platform/graphics/paint/effect_paint_property_node.cc b/third_party/blink/renderer/platform/graphics/paint/effect_paint_property_node.cc
index 23506a11..e54a6d4 100644
--- a/third_party/blink/renderer/platform/graphics/paint/effect_paint_property_node.cc
+++ b/third_party/blink/renderer/platform/graphics/paint/effect_paint_property_node.cc
@@ -35,8 +35,7 @@
     const AnimationState& animation_state) const {
   if (local_transform_space != other.local_transform_space ||
       output_clip != other.output_clip || blend_mode != other.blend_mode ||
-      view_transition_shared_element_id !=
-          other.view_transition_shared_element_id ||
+      view_transition_element_id != other.view_transition_element_id ||
       view_transition_element_resource_id !=
           other.view_transition_element_resource_id) {
     return PaintPropertyChangeType::kChangedOnlyValues;
diff --git a/third_party/blink/renderer/platform/graphics/paint/effect_paint_property_node.h b/third_party/blink/renderer/platform/graphics/paint/effect_paint_property_node.h
index 18ded5e7..42a4f0a 100644
--- a/third_party/blink/renderer/platform/graphics/paint/effect_paint_property_node.h
+++ b/third_party/blink/renderer/platform/graphics/paint/effect_paint_property_node.h
@@ -12,7 +12,7 @@
 #include "third_party/blink/renderer/platform/graphics/compositor_filter_operations.h"
 #include "third_party/blink/renderer/platform/graphics/paint/paint_property_node.h"
 #include "third_party/blink/renderer/platform/graphics/paint/transform_paint_property_node.h"
-#include "third_party/blink/renderer/platform/graphics/view_transition_shared_element_id.h"
+#include "third_party/blink/renderer/platform/graphics/view_transition_element_id.h"
 #include "third_party/blink/renderer/platform/platform_export.h"
 #include "ui/gfx/geometry/rect_f.h"
 #include "ui/gfx/geometry/rrect_f.h"
@@ -114,12 +114,12 @@
     CompositingReasons direct_compositing_reasons = CompositingReason::kNone;
     CompositorElementId compositor_element_id;
 
-    // An identifier for a view transition shared element. `id.valid()`
-    // returns true if this has been set, and false otherwise.
-    ViewTransitionElementId view_transition_shared_element_id;
+    // An identifier for a view transition element. `id.valid()` returns true if
+    // this has been set, and false otherwise.
+    ViewTransitionElementId view_transition_element_id;
 
-    // An identifier to tag shared element resources generated and cached in the
-    // Viz process. This generated resource can be used as content for other
+    // An identifier to tag transition element resources generated and cached in
+    // the Viz process. This generated resource can be used as content for other
     // elements.
     viz::ViewTransitionElementResourceId view_transition_element_resource_id;
 
@@ -306,7 +306,7 @@
   }
 
   const blink::ViewTransitionElementId& ViewTransitionElementId() const {
-    return state_.view_transition_shared_element_id;
+    return state_.view_transition_element_id;
   }
 
   const viz::ViewTransitionElementResourceId& ViewTransitionElementResourceId()
diff --git a/third_party/blink/renderer/platform/graphics/view_transition_shared_element_id.h b/third_party/blink/renderer/platform/graphics/view_transition_element_id.h
similarity index 73%
rename from third_party/blink/renderer/platform/graphics/view_transition_shared_element_id.h
rename to third_party/blink/renderer/platform/graphics/view_transition_element_id.h
index 9d49b50..ff750f1b 100644
--- a/third_party/blink/renderer/platform/graphics/view_transition_shared_element_id.h
+++ b/third_party/blink/renderer/platform/graphics/view_transition_element_id.h
@@ -2,10 +2,10 @@
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
-#ifndef THIRD_PARTY_BLINK_RENDERER_PLATFORM_GRAPHICS_VIEW_TRANSITION_SHARED_ELEMENT_ID_H_
-#define THIRD_PARTY_BLINK_RENDERER_PLATFORM_GRAPHICS_VIEW_TRANSITION_SHARED_ELEMENT_ID_H_
+#ifndef THIRD_PARTY_BLINK_RENDERER_PLATFORM_GRAPHICS_VIEW_TRANSITION_ELEMENT_ID_H_
+#define THIRD_PARTY_BLINK_RENDERER_PLATFORM_GRAPHICS_VIEW_TRANSITION_ELEMENT_ID_H_
 
-#include "cc/view_transition/view_transition_shared_element_id.h"
+#include "cc/view_transition/view_transition_element_id.h"
 
 namespace blink {
 
@@ -13,4 +13,4 @@
 
 }  //  namespace blink
 
-#endif  // THIRD_PARTY_BLINK_RENDERER_PLATFORM_GRAPHICS_VIEW_TRANSITION_SHARED_ELEMENT_ID_H_
+#endif  // THIRD_PARTY_BLINK_RENDERER_PLATFORM_GRAPHICS_VIEW_TRANSITION_ELEMENT_ID_H_
diff --git a/third_party/blink/tools/blinkpy/presubmit/audit_non_blink_usage.py b/third_party/blink/tools/blinkpy/presubmit/audit_non_blink_usage.py
index 1d77544..a557739 100755
--- a/third_party/blink/tools/blinkpy/presubmit/audit_non_blink_usage.py
+++ b/third_party/blink/tools/blinkpy/presubmit/audit_non_blink_usage.py
@@ -1718,7 +1718,7 @@
     },
     {
         'paths': [
-            'third_party/blink/renderer/platform/graphics/view_transition_shared_element_id.h'
+            'third_party/blink/renderer/platform/graphics/view_transition_element_id.h'
         ],
         'allowed': ['cc::ViewTransitionElementId'],
     },
diff --git a/third_party/blink/public/platform/web_content_settings_client.h b/third_party/blink/public/platform/web_content_settings_client.h
index 9df45cb1..99f89fa 100644
--- a/third_party/blink/public/platform/web_content_settings_client.h
+++ b/third_party/blink/public/platform/web_content_settings_client.h
@@ -114,11 +114,9 @@
   // frame.
   virtual bool ShouldAutoupgradeMixedContent() { return true; }
 
-  // Controls whether the SharedElementTransition callback needs to be larger
-  // than default.
-  virtual bool IncreaseSharedElementTransitionCallbackTimeout() const {
-    return false;
-  }
+  // Controls whether the ViewTransition callback needs to be larger than
+  // default.
+  virtual bool IncreaseViewTransitionCallbackTimeout() const { return false; }
 
   virtual ~WebContentSettingsClient() = default;
 };
diff --git a/third_party/blink/renderer/core/display_lock/display_lock_context.h b/third_party/blink/renderer/core/display_lock/display_lock_context.h
index e0388a86..b5492c0e 100644
--- a/third_party/blink/renderer/core/display_lock/display_lock_context.h
+++ b/third_party/blink/renderer/core/display_lock/display_lock_context.h
@@ -250,28 +250,29 @@
   void ScheduleTopLayerCheck();
 
   // This updates the rendering state to account for the fact that one of the
   // ancestor may be a non-root shared element, which should cause the
   // content-visibility: auto locks to be unlocked.
-  // This function is called anytime a descendant or ancestor shared element may
-  // change. Note that to determine the descendants, this function uses a
-  // document level function to mark all ancestors of shared elements. This
-  // updates all display locks on such ancestor chains, but it should be a no-op
-  // for any lock except this one. This is the most optimal way to do this and
-  // not a necessary component of the function.
-  // Note that this function also does not consider the root as a shared element
-  // (even though it might be). The reason for this is that root is treated
-  // different in SET: it is clipped by a viewport or some margin around, and
-  // it's captured by default. This means that it will frequently be in the
-  // chain of all display locks, and we want to avoid unnecessary unlocks.
-  void DetermineIfInSharedElementTransitionChain();
+  // This function is called anytime a descendant or ancestor view transition
+  // element may change. Note that to determine the descendants, this function
+  // uses a document level function to mark all ancestors of view transition
+  // elements. This updates all display locks on such ancestor chains, but it
+  // should be a no-op for any lock except this one. This is the most optimal
+  // way to do this and not a necessary component of the function.
+  // Note that this function also does not consider the root as a view
+  // transition element (even though it might be). The reason for this is that
+  // root is treated different in View Transitions: it is clipped by a viewport
+  // or some margin around, and it's captured by default. This means that it
+  // will frequently be in the chain of all display locks, and we want to avoid
+  // unnecessary unlocks.
+  void DetermineIfInViewTransitionElementChain();
   // Note that the following only checks the ancestor chain, and does not
-  // consider shared descendants. This is an optimization to be used by the
-  // document state.
-  void ResetAndDetermineIfAncestorIsSharedElement();
-  // State control for shared element render affecting state.
-  void ResetInSharedElementTransitionChain();
-  void SetInSharedElementTransitionChain();
-  bool IsInSharedElementAncestorChain() const;
+  // consider view transition descendants. This is an optimization to be used by
+  // the document state.
+  void ResetAndDetermineIfAncestorIsViewTransitionElement();
+  // State control for view transition element render affecting state.
+  void ResetInViewTransitionElementChain();
+  void SetInViewTransitionElementChain();
+  bool IsInViewTransitionElementAncestorChain() const;
 
  private:
   // Give access to |NotifyForcedUpdateScopeStarted()| and
@@ -520,7 +521,7 @@
     kAutoStateUnlockedUntilLifecycle,
     kAutoUnlockedForPrint,
     kSubtreeHasTopLayerElement,
-    kSharedElementTransitionChain,
+    kViewTransitionElementChain,
     kNumRenderAffectingStates
   };
   void SetRenderAffectingState(RenderAffectingState state, bool flag);
@@ -250,28 +250,29 @@
 
   // This updates the rendering state to account for the fact that one of the
-  // ancestor may be a non-root shared element, which should cause the
+  // ancestor may be a non-root view transition element, which should cause the
   // content-visibility: auto locks to be unlocked.
diff --git a/third_party/blink/renderer/core/display_lock/display_lock_document_state.cc b/third_party/blink/renderer/core/display_lock/display_lock_document_state.cc
index 61a8af6..0efcc566 100644
--- a/third_party/blink/renderer/core/display_lock/display_lock_document_state.cc
+++ b/third_party/blink/renderer/core/display_lock/display_lock_document_state.cc
@@ -251,40 +251,44 @@
   return had_locked_ancestor;
 }
 
-void DisplayLockDocumentState::NotifySharedElementPseudoTreeChanged() {
+void DisplayLockDocumentState::NotifyViewTransitionPseudoTreeChanged() {
   // Note that this function doesn't use
   // DisplayLockContext::DetermineIfInSharedElementTransitionChain, since that
   // would mean we have to call UpdateSharedElementAncestorLocks for each lock.
   // This function only calls it once by hoisting it out of the context calls.
 
   // Reset the flag and determine if the ancestor is shared element.
   for (auto context : display_lock_contexts_)
-    context->ResetAndDetermineIfAncestorIsSharedElement();
+    context->ResetAndDetermineIfAncestorIsViewTransitionElement();
 
-  // Also process the shared elements to check if the shared element's ancestors
-  // are locks. These two parts give us the full chain (either locks are
-  // ancestors of shared or shared are ancestor of locks).
-  UpdateSharedElementAncestorLocks();
+  // Also process the view transition elements to check if their ancestors are
+  // locks. These two parts give us the full chain (either locks are ancestors
+  // of transition element or transition elements are ancestors of locks).
+  UpdateViewTransitionElementAncestorLocks();
 }
 
-void DisplayLockDocumentState::UpdateSharedElementAncestorLocks() {
+void DisplayLockDocumentState::UpdateViewTransitionElementAncestorLocks() {
   auto* transition = ViewTransitionUtils::GetActiveTransition(*document_);
   if (!transition)
     return;
 
-  const auto& shared_elements = transition->GetTransitioningElements();
-  for (auto element : shared_elements) {
+  const auto& transitioning_elements = transition->GetTransitioningElements();
+  for (auto element : transitioning_elements) {
     auto* ancestor = element.Get();
     // When the element which has c-v:auto is itself a shared element, marking
     // it as such could go in either walk (from the function naming) but it
     // happens in the ancestor chain check and skipped here. This DCHECK
     // verifies this.
     DCHECK(!element->GetDisplayLockContext() ||
-           element->GetDisplayLockContext()->IsInSharedElementAncestorChain());
+           element->GetDisplayLockContext()
+               ->IsInViewTransitionElementAncestorChain());
 
     while ((ancestor = FlatTreeTraversal::ParentElement(*ancestor))) {
       if (auto* context = ancestor->GetDisplayLockContext())
-        context->SetInSharedElementTransitionChain();
+        context->SetInViewTransitionElementChain();
     }
   }
 }
@@ -251,40 +251,44 @@
   // Note that this function doesn't use
-  // DisplayLockContext::DetermineIfInSharedElementTransitionChain, since that
-  // would mean we have to call UpdateSharedElementAncestorLocks for each lock.
-  // This function only calls it once by hoisting it out of the context calls.
+  // DisplayLockContext::DetermineIfInViewTransitionElementChain, since that
+  // would mean we have to call UpdateViewTransitionElementAncestorLocks for
+  // each lock. This function only calls it once by hoisting it out of the
+  // context calls.
+  // TODO(crbug.com/1409132): This needs to be updated to match the new desired
+  // behavior for content-visibility: auto in a snapshot descendent.
 
@@ -251,40 +251,44 @@
 
-  // Reset the flag and determine if the ancestor is shared element.
+  // Reset the flag and determine if the ancestor is a view transition element.
   for (auto context : display_lock_contexts_)
@@ -251,40 +251,44 @@
     auto* ancestor = element.Get();
-    // When the element which has c-v:auto is itself a shared element, marking
-    // it as such could go in either walk (from the function naming) but it
-    // happens in the ancestor chain check and skipped here. This DCHECK
+    // When the element which has c-v:auto is itself a view transition element,
+    // marking it as such could go in either walk (from the function naming) but
+    // it happens in the ancestor chain check and skipped here. This DCHECK
     // verifies this.
     DCHECK(!element->GetDisplayLockContext() ||
diff --git a/third_party/blink/renderer/core/display_lock/display_lock_document_state.h b/third_party/blink/renderer/core/display_lock/display_lock_document_state.h
index 4ac921c..cd1bf0c 100644
--- a/third_party/blink/renderer/core/display_lock/display_lock_document_state.h
+++ b/third_party/blink/renderer/core/display_lock/display_lock_document_state.h
@@ -86,12 +86,13 @@
   // Notify the display locks that selection was removed.
   void NotifySelectionRemoved();
 
-  // Notify the display locks that shared elements have changed.
-  void NotifySharedElementPseudoTreeChanged();
+  // Notify the display locks that view transition pseudo elements have
+  // changed.
+  void NotifyViewTransitionPseudoTreeChanged();
 
-  // Updates only the ancestor locks of the view transition elements.
-  // This is an optimization to be used by the display lock context.
-  void UpdateSharedElementAncestorLocks();
+  // Updates only the ancestor locks of the view transition elements. This is an
+  // optimization to be used by the display lock context.
+  void UpdateViewTransitionElementAncestorLocks();
 
   // This is called when the forced scope is created or destroyed in
   // |ScopedForcedUpdate::Impl|. This is used to ensure that we can create new
diff --git a/third_party/blink/renderer/core/page/page_animator.cc b/third_party/blink/renderer/core/page/page_animator.cc
index dd84ca2..ef99bfd 100644
--- a/third_party/blink/renderer/core/page/page_animator.cc
+++ b/third_party/blink/renderer/core/page/page_animator.cc
@@ -101,15 +101,14 @@
     animation_host->SetHasSmilAnimation(has_smil_animation_);
     animation_host->SetCurrentFrameHadRaf(current_frame_had_raf_);
     animation_host->SetNextFrameHasPendingRaf(next_frame_has_pending_raf_);
-    animation_host->SetHasSharedElementTransition(
-        has_shared_element_transition_);
+    animation_host->SetHasViewTransition(has_view_transition_);
   }
   has_canvas_invalidation_ = false;
   has_inline_style_mutation_ = false;
   has_smil_animation_ = false;
   current_frame_had_raf_ = false;
   // next_frame_has_pending_raf_ is reset at PostAnimate().
   // has_shared_element_transition_ is reset when the transition ends.
 }
 
 void PageAnimator::SetSuppressFrameRequestsWorkaroundFor704763Only(
@@ -137,9 +136,8 @@
   next_frame_has_pending_raf_ = true;
 }
 
-void PageAnimator::SetHasSharedElementTransition(
-    bool has_shared_element_transition) {
-  has_shared_element_transition_ = has_shared_element_transition;
+void PageAnimator::SetHasViewTransition(bool has_view_transition) {
+  has_view_transition_ = has_view_transition;
 }
 
 DISABLE_CFI_PERF
@@ -101,15 +101,14 @@
   current_frame_had_raf_ = false;
   // next_frame_has_pending_raf_ is reset at PostAnimate().
-  // has_shared_element_transition_ is reset when the transition ends.
+  // has_view_transition_ is reset when the transition ends.
 }
 
diff --git a/third_party/blink/renderer/core/paint/compositing/compositing_reason_finder.cc b/third_party/blink/renderer/core/paint/compositing/compositing_reason_finder.cc
index 1dcc683f..b0dcdff9 100644
--- a/third_party/blink/renderer/core/paint/compositing/compositing_reason_finder.cc
+++ b/third_party/blink/renderer/core/paint/compositing/compositing_reason_finder.cc
@@ -346,11 +346,12 @@
 
   if (auto* transition =
           ViewTransitionUtils::GetActiveTransition(object.GetDocument())) {
-    // Note that `NeedsSharedElementEffectNode` returns true for values that are
-    // in the non-transition-pseudo tree DOM. That is, things like layout view
-    // or the shared elements that we are transitioning.
-    if (transition->NeedsSharedElementEffectNode(object))
-      reasons |= CompositingReason::kViewTransitionSharedElement;
+    // Note that `NeedsViewTransitionEffectNode` returns true for values that
+    // are in the non-transition-pseudo tree DOM. That is, things like layout
+    // view or the view transition elements that we are transitioning.
+    if (transition->NeedsViewTransitionEffectNode(object)) {
+      reasons |= CompositingReason::kViewTransitionElement;
+    }
   }
 
   return reasons;
diff --git a/third_party/blink/renderer/core/paint/paint_property_tree_printer.cc b/third_party/blink/renderer/core/paint/paint_property_tree_printer.cc
index b2e7f2a..380f48d 100644
--- a/third_party/blink/renderer/core/paint/paint_property_tree_printer.cc
+++ b/third_party/blink/renderer/core/paint/paint_property_tree_printer.cc
@@ -54,7 +54,7 @@
   }
 
   void CollectNodes(const LayoutObject& object) {
-    Traits::AddSharedElementTransitionProperties(object, *this);
+    Traits::AddViewTransitionProperties(object, *this);
 
     for (const auto* fragment = &object.FirstFragment(); fragment;
          fragment = fragment->NextFragment()) {
@@ -95,7 +95,7 @@
     printer.AddNode(properties.ScrollTranslation());
     printer.AddNode(properties.TransformIsolationNode());
   }
-  static void AddSharedElementTransitionProperties(
+  static void AddViewTransitionProperties(
       const LayoutObject& object,
       PropertyTreePrinter<TransformPaintPropertyNodeOrAlias>& printer) {}
   static void AddOtherProperties(
@@ -123,7 +123,7 @@
     printer.AddNode(properties.OverflowClip());
     printer.AddNode(properties.ClipIsolationNode());
   }
-  static void AddSharedElementTransitionProperties(
+  static void AddViewTransitionProperties(
       const LayoutObject& object,
       PropertyTreePrinter<ClipPaintPropertyNodeOrAlias>& printer) {}
   static void AddOtherProperties(
@@ -150,15 +150,16 @@
     printer.AddNode(properties.EffectIsolationNode());
   }
 
-  static void AddSharedElementTransitionProperties(
+  static void AddViewTransitionProperties(
       const LayoutObject& object,
       PropertyTreePrinter<EffectPaintPropertyNodeOrAlias>& printer) {
     auto* transition =
         ViewTransitionUtils::GetActiveTransition(object.GetDocument());
-    // `NeedsSharedElementEffectNode` is an indirect way to see if the object is
-    // participating in the transition.
-    if (!transition || !transition->NeedsSharedElementEffectNode(object))
+    // `NeedsViewTransitionEffectNode` is an indirect way to see if the object
+    // is participating in the transition.
+    if (!transition || !transition->NeedsViewTransitionEffectNode(object)) {
       return;
+    }
 
     printer.AddNode(transition->GetEffect(object));
   }
@@ -185,7 +186,7 @@
     printer.AddNode(properties.Scroll());
   }
 
-  static void AddSharedElementTransitionProperties(
+  static void AddViewTransitionProperties(
       const LayoutObject& object,
       PropertyTreePrinter<ScrollPaintPropertyNode>& printer) {}
   static void AddOtherProperties(
diff --git a/third_party/blink/renderer/core/view_transition/view_transition.h b/third_party/blink/renderer/core/view_transition/view_transition.h
index b2993ae4..049a411 100644
--- a/third_party/blink/renderer/core/view_transition/view_transition.h
+++ b/third_party/blink/renderer/core/view_transition/view_transition.h
@@ -24,7 +24,7 @@
 #include "third_party/blink/renderer/platform/bindings/script_wrappable.h"
 #include "third_party/blink/renderer/platform/graphics/paint/clip_paint_property_node.h"
 #include "third_party/blink/renderer/platform/graphics/paint/effect_paint_property_node.h"
-#include "third_party/blink/renderer/platform/graphics/view_transition_shared_element_id.h"
+#include "third_party/blink/renderer/platform/graphics/view_transition_element_id.h"
 #include "third_party/blink/renderer/platform/heap/forward.h"
 #include "third_party/blink/renderer/platform/wtf/wtf_size_t.h"
 
@@ -105,18 +105,18 @@
   // ActiveScriptWrappable functionality.
   bool HasPendingActivity() const override;
 
-  // Returns true if this object needs to create an EffectNode for the shared
-  // element transition.
-  bool NeedsSharedElementEffectNode(const LayoutObject& object) const;
+  // Returns true if this object needs to create an EffectNode for its element
+  // transition.
+  bool NeedsViewTransitionEffectNode(const LayoutObject& object) const;
 
   // Returns true if this object is painted via pseudo elements. Note that this
   // is different from NeedsSharedElementFromEffectNode() since the root may not
   // be a shared element, but require an effect node.
   bool IsRepresentedViaPseudoElements(const LayoutObject& object) const;
 
   // Updates an effect node. This effect populates the shared element id and the
   // shared element resource id. The return value is a result of updating the
   // effect node.
   PaintPropertyChangeType UpdateEffect(
       const LayoutObject& object,
       const EffectPaintPropertyNodeOrAlias& current_effect,
@@ -105,18 +105,18 @@
 
   // Returns true if this object is painted via pseudo elements. Note that this
-  // is different from NeedsSharedElementFromEffectNode() since the root may not
-  // be a shared element, but require an effect node.
+  // is different from NeedsViewTransitionEffectNode() since the root may not
+  // be a transitioning element, but require an effect node.
   bool IsRepresentedViaPseudoElements(const LayoutObject& object) const;
 
@@ -105,18 +105,18 @@
   bool IsRepresentedViaPseudoElements(const LayoutObject& object) const;
 
-  // Updates an effect node. This effect populates the shared element id and the
-  // shared element resource id. The return value is a result of updating the
-  // effect node.
+  // Updates an effect node. This effect populates the view transition element
+  // id and the shared element resource id. The return value is a result of
+  // updating the effect node.
   PaintPropertyChangeType UpdateEffect(
       const LayoutObject& object,
diff --git a/third_party/blink/renderer/core/view_transition/view_transition_style_tracker.cc b/third_party/blink/renderer/core/view_transition/view_transition_style_tracker.cc
index 0914d1f..84b1e9ef 100644
--- a/third_party/blink/renderer/core/view_transition/view_transition_style_tracker.cc
+++ b/third_party/blink/renderer/core/view_transition/view_transition_style_tracker.cc
@@ -133,8 +133,8 @@
         snapshot_id = it->value->old_snapshot_id;
       } else {
         // If we're being called with a name that isn't an old_root name and
-        // it's not an element shared element, it must mean we have it as a new
-        // root name.
+        // it's not a transition element, it must mean we have it as a new root
+        // name.
         DCHECK(style_tracker_->new_root_data_);
         DCHECK(style_tracker_->new_root_data_->names.Contains(
             view_transition_name()));
@@ -151,7 +151,7 @@
         snapshot_id = it->value->new_snapshot_id;
       } else {
         // If we're being called with a name that isn't a new_root name and it's
-        // not an element shared element, it must mean we have it as an old root
+        // not a transition element, it must mean we have it as an old root
         // name.
         DCHECK(style_tracker_->old_root_data_);
         DCHECK(style_tracker_->old_root_data_->names.Contains(
@@ -223,13 +223,14 @@
   document_->AddConsoleMessage(console_message);
 }
 
-void ViewTransitionStyleTracker::AddSharedElement(Element* element,
-                                                  const AtomicString& name) {
+void ViewTransitionStyleTracker::AddTransitionElement(
+    Element* element,
+    const AtomicString& name) {
   DCHECK(element);
 
   // Insert an empty hash set for the element if it doesn't exist, or get it if
   // it does.
-  auto& value = pending_shared_element_names_
+  auto& value = pending_transition_element_names_
                     .insert(element, HashSet<std::pair<AtomicString, int>>())
                     .stored_value->value;
   // Find the existing name if one is there. If it is there, do nothing.
@@ -297,7 +298,7 @@
   return false;
 }
 
-void ViewTransitionStyleTracker::AddSharedElementsFromCSS() {
+void ViewTransitionStyleTracker::AddTransitionElementsFromCSS() {
   DCHECK(document_ && document_->View());
 
   // We need our paint layers, and z-order lists which is done during
@@ -305,13 +306,13 @@
   DCHECK_GE(document_->Lifecycle().GetState(),
             DocumentLifecycle::kCompositingInputsClean);
 
-  AddSharedElementsFromCSSRecursive(
+  AddTransitionElementsFromCSSRecursive(
       document_->GetLayoutView()->PaintingLayer());
 }
 
-void ViewTransitionStyleTracker::AddSharedElementsFromCSSRecursive(
+void ViewTransitionStyleTracker::AddTransitionElementsFromCSSRecursive(
     PaintLayer* root) {
-  // We want to call AddSharedElements in the order in which
+  // We want to call AddTransitionElements in the order in which
   // PaintLayerPaintOrderIterator would cause us to paint the elements.
   // Specifically, parents are added before their children, and lower z-index
   // children are added before higher z-index children. Given that, what we
@@ -319,17 +320,17 @@
   // PaintLayerPaintOrderIterator which will return values in the correct
   // z-index order.
   //
   // Note that the order of calls to AddSharedElement determines the DOM order
   // of pseudo-elements constructed to represent the shared elements, which by
   // default will also represent the paint order of the pseudo-elements (unless
   // changed by something like z-index on the pseudo-elements).
   auto& root_object = root->GetLayoutObject();
   auto& root_style = root_object.StyleRef();
   if (root_style.ViewTransitionName()) {
     DCHECK(root_object.GetNode());
     DCHECK(root_object.GetNode()->IsElementNode());
-    AddSharedElement(DynamicTo<Element>(root_object.GetNode()),
-                     root_style.ViewTransitionName());
+    AddTransitionElement(DynamicTo<Element>(root_object.GetNode()),
+                         root_style.ViewTransitionName());
   }
 
   if (root_object.ChildPaintBlockedByDisplayLock())
@@ -337,7 +338,7 @@
 
   PaintLayerPaintOrderIterator child_iterator(root, kAllChildren);
   while (auto* child = child_iterator.Next()) {
-    AddSharedElementsFromCSSRecursive(child);
+    AddTransitionElementsFromCSSRecursive(child);
   }
 }
 
@@ -378,7 +379,7 @@
   VectorOf<FlatData> flat_list;
 
   // Flatten it.
-  for (auto& [element, names] : pending_shared_element_names_) {
+  for (auto& [element, names] : pending_transition_element_names_) {
     DCHECK(element->GetLayoutObject());
 
     const bool is_root = element->IsDocumentElement();
@@ -430,7 +431,7 @@
 bool ViewTransitionStyleTracker::Capture() {
   DCHECK_EQ(state_, State::kIdle);
 
   // Flatten `pending_shared_element_names_` into a vector of names and
   // elements. This process also verifies that the name-element combinations are
   // valid.
   VectorOf<AtomicString> transition_names;
@@ -488,7 +489,7 @@
   InvalidateStyle();
 
   set_element_sequence_id_ = 0;
-  pending_shared_element_names_.clear();
+  pending_transition_element_names_.clear();
 
   return true;
 }
@@ -504,8 +505,8 @@
 
   // Since the elements will be unset, we need to invalidate their style first.
   // TODO(vmpstr): We don't have to invalidate the pseudo styles at this point,
-  // just the shared elements. We can split InvalidateStyle() into two functions
-  // as an optimization.
+  // just the transition elements. We can split InvalidateStyle() into two
+  // functions as an optimization.
   InvalidateStyle();
 
   for (auto& entry : element_data_map_) {
@@ -517,7 +518,7 @@
 }
 
 VectorOf<Element> ViewTransitionStyleTracker::GetTransitioningElements() const {
-  // In stable states, we don't have shared elements.
+  // In stable states, we don't have transitioning elements.
   if (state_ == State::kIdle || state_ == State::kCaptured)
     return {};
 
@@ -532,7 +533,7 @@
 bool ViewTransitionStyleTracker::Start() {
   DCHECK_EQ(state_, State::kCaptured);
 
   // Flatten `pending_shared_element_names_` into a vector of names and
   // elements. This process also verifies that the name-element combinations are
   // valid.
   VectorOf<AtomicString> transition_names;
@@ -592,8 +593,8 @@
   if (!found_new_names && new_root_data_) {
     DCHECK(old_root_data_);
     for (const auto& new_name : new_root_data_->names) {
-      // If the new root name is not also an old root name and it isn't a shared
-      // element name, then we have a new name.
+      // If the new root name is not also an old root name and it isn't a
+      // transition element name, then we have a new name.
       if (!old_root_data_->names.Contains(new_name) &&
           !element_data_map_.Contains(new_name)) {
         found_new_names = true;
@@ -643,7 +644,7 @@
   InvalidateStyle();
 
   if (auto* page = document_->GetPage())
-    page->Animator().SetHasSharedElementTransition(true);
+    page->Animator().SetHasViewTransition(true);
   return true;
 }
 
@@ -661,18 +662,18 @@
   InvalidateHitTestingCache();
 
   // We need a style invalidation to remove the pseudo element tree. This needs
-  // to be done before we clear the data, since we need to invalidate the shared
-  // elements stored in `element_data_map_`.
+  // to be done before we clear the data, since we need to invalidate the
+  // transition elements stored in `element_data_map_`.
   InvalidateStyle();
 
   element_data_map_.clear();
-  pending_shared_element_names_.clear();
+  pending_transition_element_names_.clear();
   set_element_sequence_id_ = 0;
   old_root_data_.reset();
   new_root_data_.reset();
   document_->GetStyleEngine().SetViewTransitionNames({});
   if (auto* page = document_->GetPage())
-    page->Animator().SetHasSharedElementTransition(false);
+    page->Animator().SetHasViewTransition(false);
 }
 
 void ViewTransitionStyleTracker::UpdateElementIndicesAndSnapshotId(
@@ -950,7 +951,7 @@
       element_data->effect_node =
           EffectPaintPropertyNode::Create(current_effect, std::move(state));
 #if DCHECK_IS_ON()
-      element_data->effect_node->SetDebugName("SharedElementTransition");
+      element_data->effect_node->SetDebugName("ViewTransition");
 #endif
       return PaintPropertyChangeType::kNodeAddedOrRemoved;
     }
@@ -968,7 +969,7 @@
     root_effect_node_ =
         EffectPaintPropertyNode::Create(current_effect, std::move(state));
 #if DCHECK_IS_ON()
-    root_effect_node_->SetDebugName("SharedElementTransition");
+    root_effect_node_->SetDebugName("ViewTransition");
 #endif
     return PaintPropertyChangeType::kNodeAddedOrRemoved;
   }
@@ -993,8 +994,8 @@
   return root_effect_node_.get();
 }
 
-bool ViewTransitionStyleTracker::IsSharedElement(Node* node) const {
-  // In stable states, we don't have shared elements.
+bool ViewTransitionStyleTracker::IsTransitionElement(Node* node) const {
+  // In stable states, we don't have transition elements.
   if (state_ == State::kIdle || state_ == State::kCaptured)
     return false;
 
@@ -1198,14 +1199,14 @@
     if (!object)
       continue;
 
-    // We propagate the shared element id on an effect node for the object. This
-    // means that we should update the paint properties to update the shared
-    // element id.
+    // We propagate the view transition element id on an effect node for the
+    // object. This means that we should update the paint properties to update
+    // the view transition element id.
     object->SetNeedsPaintPropertyUpdate();
   }
 
   document_->GetDisplayLockDocumentState()
-      .NotifySharedElementPseudoTreeChanged();
+      .NotifyViewTransitionPseudoTreeChanged();
 }
 
 HashSet<AtomicString> ViewTransitionStyleTracker::AllRootTags() const {
@@ -1247,21 +1248,21 @@
   // 2. A name is an old root only (exit animation for root). The style is set
   // up in the AllrootTags loop and fades out through AnimationUAStyles.
   //
-  // 3. A name is an old root and a new shared element. The AllRootTags loop
+  // 3. A name is an old root and a new transition element. The AllRootTags loop
   // skips this name. The element map loop updates the container for the new
-  // shared element size and transform. The animation code of that loop adds an
-  // animation from old root size and identity matrix.
+  // transition element size and transform. The animation code of that loop adds
+  // an animation from old root size and identity matrix.
   //
   // 4. A name is a new root only (entry animation for root). Its only visited
   // in AllRootTags and its a default fade-in.
   //
-  // 5. A name is a new root and old shared element. We visit it in AllRootTags
-  // to set up the destination state. We skip setting its styles in the
-  // `element_data_map_` loop since latest value comes from AllRootTags. We do
-  // set the animation in that loop since we need the "from" state.
+  // 5. A name is a new root and old transition element. We visit it in
+  // AllRootTags to set up the destination state. We skip setting its styles in
+  // the `element_data_map_` loop since latest value comes from AllRootTags. We
+  // do set the animation in that loop since we need the "from" state.
   //
-  // 6. A name is a new and old shared element (or maybe exit/enter for shared
-  // element only -- no roots involved. Everything is done in the
+  // 6. A name is a new and old transition element (or maybe exit/enter for
+  // transition element only -- no roots involved. Everything is done in the
   // `element_data_map_` loop.
 
   // Size and position the root container behind any viewport insetting widgets
@@ -1327,7 +1328,7 @@
                                  element_data->container_properties.back(),
                                  element_data->container_writing_mode);
 
-      // Incoming inset also only makes sense if the name is a new shared
+      // Incoming inset also only makes sense if the name is a new transition
       // element (not a new root).
       const bool has_new_image = element_data->new_snapshot_id.IsValid();
       absl::optional<String> incoming_inset =
@@ -1345,8 +1346,8 @@
       }
     }
 
-    // Outgoing inset only makes sense if the name is an old shared element (not
-    // an old root).
+    // Outgoing inset only makes sense if the name is an old transition element
+    // (not an old root).
     const bool has_old_image = element_data->old_snapshot_id.IsValid();
     if (has_old_image && !name_is_old_root) {
       absl::optional<String> outgoing_inset = ComputeInsetDifference(
@@ -1398,7 +1399,7 @@
 void ViewTransitionStyleTracker::Trace(Visitor* visitor) const {
   visitor->Trace(document_);
   visitor->Trace(element_data_map_);
-  visitor->Trace(pending_shared_element_names_);
+  visitor->Trace(pending_transition_element_names_);
 }
 
 void ViewTransitionStyleTracker::InvalidateHitTestingCache() {
@@ -1417,7 +1418,7 @@
 }
 
 // TODO(vmpstr): We need to write tests for the following:
-// * A local transform on the shared element.
+// * A local transform on the transition element.
 // * A transform on an ancestor which changes its screen space transform.
 LayoutSize ViewTransitionStyleTracker::ElementData::GetIntrinsicSize(
     bool use_cached_data) {
@@ -1444,7 +1445,7 @@
 PhysicalRect ViewTransitionStyleTracker::ComputeVisualOverflowRect(
     LayoutBoxModelObject& box,
     LayoutBoxModelObject* ancestor) {
-  if (ancestor && IsSharedElement(box.GetNode())) {
+  if (ancestor && IsTransitionElement(box.GetNode())) {
     return {};
   }
 
@@ -319,17 +320,17 @@
   // z-index order.
   //
-  // Note that the order of calls to AddSharedElement determines the DOM order
-  // of pseudo-elements constructed to represent the shared elements, which by
-  // default will also represent the paint order of the pseudo-elements (unless
-  // changed by something like z-index on the pseudo-elements).
+  // Note that the order of calls to AddTransitionElement determines the DOM
+  // order of pseudo-elements constructed to represent the transition elements,
+  // which by default will also represent the paint order of the pseudo-elements
+  // (unless changed by something like z-index on the pseudo-elements).
   auto& root_object = root->GetLayoutObject();
   auto& root_style = root_object.StyleRef();
@@ -430,7 +431,7 @@
   DCHECK_EQ(state_, State::kIdle);
 
-  // Flatten `pending_shared_element_names_` into a vector of names and
+  // Flatten `pending_transition_element_names_` into a vector of names and
   // elements. This process also verifies that the name-element combinations are
   // valid.
@@ -532,7 +533,7 @@
   DCHECK_EQ(state_, State::kCaptured);
 
-  // Flatten `pending_shared_element_names_` into a vector of names and
+  // Flatten `pending_transition_element_names_` into a vector of names and
   // elements. This process also verifies that the name-element combinations are
   // valid.
diff --git a/third_party/blink/renderer/core/view_transition/view_transition_style_tracker.h b/third_party/blink/renderer/core/view_transition/view_transition_style_tracker.h
index 0c7093b..ebc7ec4 100644
--- a/third_party/blink/renderer/core/view_transition/view_transition_style_tracker.h
+++ b/third_party/blink/renderer/core/view_transition/view_transition_style_tracker.h
@@ -14,7 +14,7 @@
 #include "third_party/blink/renderer/platform/allow_discouraged_type.h"
 #include "third_party/blink/renderer/platform/geometry/layout_size.h"
 #include "third_party/blink/renderer/platform/graphics/paint/effect_paint_property_node.h"
-#include "third_party/blink/renderer/platform/graphics/view_transition_shared_element_id.h"
+#include "third_party/blink/renderer/platform/graphics/view_transition_element_id.h"
 #include "third_party/blink/renderer/platform/heap/collection_support/heap_hash_map.h"
 #include "third_party/blink/renderer/platform/heap/heap_traits.h"
 #include "ui/gfx/geometry/transform.h"
@@ -31,8 +31,9 @@
 //    are generated after the new Document has loaded and the transition can be
 //    started.
 //
 // 2) Tracking changes in the state of shared elements that are mirrored in the
 //    style for their corresponding pseudo element. For example, if a shared
 //    element's size or viewport space transform is updated. This data is used
 //    to generate a dynamic UA stylesheet for these pseudo elements.
 //
@@ -66,7 +67,7 @@
   ViewTransitionStyleTracker(Document& document, ViewTransitionState);
   ~ViewTransitionStyleTracker();
 
-  void AddSharedElementsFromCSS();
+  void AddTransitionElementsFromCSS();
 
   // Returns true if the pseudo element corresponding to the given id and name
   // is the only child.
@@ -141,7 +142,7 @@
 
   int CapturedTagCount() const { return captured_name_count_; }
 
-  bool IsSharedElement(Node* node) const;
+  bool IsTransitionElement(Node* node) const;
 
   // This function represents whether root itself is participating in the
   // transition (i.e. it has a name in the current phase). Note that we create
@@ -212,7 +213,7 @@
     // any of element's own effects, in a pseudo element layer.
     scoped_refptr<EffectPaintPropertyNode> effect_node;
 
-    // Index to add to the view transition shared element id.
+    // Index to add to the view transition element id.
     int element_index;
 
     // The visual overflow rect for this element. This is used to compute
@@ -237,12 +238,12 @@
   void EndTransition();
 
   void AddConsoleError(String message, Vector<DOMNodeId> related_nodes = {});
-  void AddSharedElement(Element*, const AtomicString&);
+  void AddTransitionElement(Element*, const AtomicString&);
   bool FlattenAndVerifyElements(VectorOf<Element>&,
                                 VectorOf<AtomicString>&,
                                 absl::optional<RootData>&);
 
-  void AddSharedElementsFromCSSRecursive(PaintLayer*);
+  void AddTransitionElementsFromCSSRecursive(PaintLayer*);
 
   int OldRootDataTagSize() const {
     return old_root_data_ ? old_root_data_->names.size() : 0;
@@ -301,7 +302,7 @@
   // by script for the start phase.
   int set_element_sequence_id_ = 0;
   HeapHashMap<Member<Element>, HashSet<std::pair<AtomicString, int>>>
-      pending_shared_element_names_;
+      pending_transition_element_names_;
 
   // This vector is passed as constructed to cc's view transition request,
   // so this uses the std::vector for that reason, instead of WTF::Vector.
@@ -31,8 +31,9 @@
 //    started.
 //
-// 2) Tracking changes in the state of shared elements that are mirrored in the
-//    style for their corresponding pseudo element. For example, if a shared
+// 2) Tracking changes in the state of transition elements that are mirrored in
+// the
+//    style for their corresponding pseudo element. For example, if a transition
 //    element's size or viewport space transform is updated. This data is used
 //    to generate a dynamic UA stylesheet for these pseudo elements.